@@ -431,10 +431,12 @@ class ParamEditor(QtWidgets.QDockWidget):
     return proc
 
   @classmethod
-  def buildClsToolsEditor(cls, forCls: type, name=None):
+  def buildClsToolsEditor(cls, forCls: type, name: str=None):
     groupName = clsNameOrGroup(forCls)
     lowerGroupName = groupName.lower()
     if name is None:
+      name = groupName
+    if not groupName.endswith('Tools'):
       name = groupName + ' Tools'
     toolsEditor = cls(saveDir=None,
                               fileType=lowerGroupName.replace(' ', '') + 'toolsEditor',
